@@ -26,8 +26,9 @@
 #endif
 
 #include <gtk/gtk.h>
-
+#ifdef ENABLE_X11
 #include <gdk/gdkx.h>
+#endif
 
 #include <libxfce4util/libxfce4util.h>
 #include <garcon/garcon.h>
@@ -76,7 +77,7 @@ main(int argc,
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string());
-        g_print ("%s\n", "Copyright (c) 2008-2024");
+        g_print ("%s\n", "Copyright (c) 2008-2023");
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -108,8 +109,11 @@ main(int argc,
         g_message ("Dialog \"%s\" not found.", opt_dialog);
     }
 
+#ifdef ENABLE_X11
     /* To prevent the settings dialog to be saved in the session */
-    gdk_x11_set_sm_client_id ("FAKE ID");
+    if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+        gdk_x11_set_sm_client_id ("FAKE ID");
+#endif
 
     gtk_main();
 
